summaryrefslogtreecommitdiffstats
path: root/kdeui/kiconview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdeui/kiconview.cpp')
-rw-r--r--kdeui/kiconview.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/kdeui/kiconview.cpp b/kdeui/kiconview.cpp
index 13b6183ad..357d6b2c4 100644
--- a/kdeui/kiconview.cpp
+++ b/kdeui/kiconview.cpp
@@ -217,7 +217,7 @@ void KIconView::slotAutoSelect()
blockSignals( block );
viewport()->setUpdatesEnabled( update );
- repaintContents( redraw, false );
+ tqrepaintContents( redraw, false );
emit selectionChanged();
@@ -258,7 +258,7 @@ void KIconView::emitExecute( TQIconViewItem *item, const TQPoint &pos )
void KIconView::updateDragHoldItem( TQDropEvent *e )
{
- TQIconViewItem *item = findItem( e->pos() );
+ TQIconViewItem *item = tqfindItem( e->pos() );
if ( d->dragHoldItem != item)
{
@@ -307,10 +307,10 @@ void KIconView::contentsMouseDoubleClickEvent ( TQMouseEvent * e )
{
TQIconView::contentsMouseDoubleClickEvent( e );
- TQIconViewItem* item = findItem( e->pos() );
+ TQIconViewItem* item = tqfindItem( e->pos() );
if( item ) {
- if( (e->button() == LeftButton) && !m_bUseSingle )
+ if( (e->button() == Qt::LeftButton) && !m_bUseSingle )
emitExecute( item, e->globalPos() );
emit doubleClicked( item, e->globalPos() );
@@ -324,7 +324,7 @@ void KIconView::slotMouseButtonClicked( int btn, TQIconViewItem *item, const TQP
if( d->doubleClickIgnoreTimer.isActive() )
return; // Ignore double click
- if( (btn == LeftButton) && item )
+ if( (btn == Qt::LeftButton) && item )
emitExecute( item, pos );
}
@@ -417,7 +417,7 @@ TQFontMetrics *KIconView::itemFontMetrics() const
TQPixmap KIconView::selectedIconPixmap( TQPixmap *pix, const TQColor &col ) const
{
TQPixmap m;
- if ( d->maskCache.find( TQString::number( pix->serialNumber() ), m ) )
+ if ( d->maskCache.tqfind( TQString::number( pix->serialNumber() ), m ) )
return m;
m = KPixmapEffect::selectedPixmap( KPixmap(*pix), col );
d->maskCache.insert( TQString::number( pix->serialNumber() ), m );
@@ -485,7 +485,7 @@ void KIconViewItem::calcRect( const TQString& text_ )
KIconView *view = static_cast<KIconView *>(iconView());
TQRect itemIconRect = pixmapRect();
TQRect itemTextRect = textRect();
- TQRect itemRect = rect();
+ TQRect tqitemRect = rect();
int pw = 0;
int ph = 0;
@@ -507,9 +507,9 @@ void KIconViewItem::calcRect( const TQString& text_ )
itemIconRect.setWidth( pw );
#if 1 // FIXME
// There is a bug in Qt which prevents the item from being placed
// properly when the pixmapRect is not at the top of the itemRect, so we
// have to increase the height of the pixmapRect and leave it at the top
- // of the itemRect...
+ // of the tqitemRect...
if ( d && !d->m_pixmapSize.isNull() )
itemIconRect.setHeight( d->m_pixmapSize.height() + 2 );
else
@@ -574,8 +574,8 @@ void KIconViewItem::calcRect( const TQString& text_ )
h = itemTextRect.height() + itemIconRect.height() + 1;
}
- itemRect.setWidth( w );
- itemRect.setHeight( h );
+ tqitemRect.setWidth( w );
+ tqitemRect.setHeight( h );
int width = QMAX( w, TQApplication::globalStrut().width() ); // see TQIconViewItem::width()
int height = QMAX( h, TQApplication::globalStrut().height() ); // see TQIconViewItem::height()
itemTextRect = TQRect( ( width - itemTextRect.width() ) / 2, height - itemTextRect.height(),
@@ -597,8 +597,8 @@ void KIconViewItem::calcRect( const TQString& text_ )
h = QMAX( itemTextRect.height(), itemIconRect.height() );
w = itemTextRect.width() + itemIconRect.width() + 1;
- itemRect.setWidth( w );
- itemRect.setHeight( h );
+ tqitemRect.setWidth( w );
+ tqitemRect.setHeight( h );
int width = QMAX( w, TQApplication::globalStrut().width() ); // see TQIconViewItem::width()
int height = QMAX( h, TQApplication::globalStrut().height() ); // see TQIconViewItem::height()
@@ -621,8 +621,8 @@ void KIconViewItem::calcRect( const TQString& text_ )
setPixmapRect( itemIconRect );
if ( itemTextRect != textRect() )
setTextRect( itemTextRect );
- if ( itemRect != rect() )
- setItemRect( itemRect );
+ if ( tqitemRect != rect() )
+ setItemRect( tqitemRect );
// Done by setPixmapRect, setTextRect and setItemRect ! [and useless if no rect changed]
//view->updateItemContainer( this );
@@ -680,7 +680,7 @@ void KIconViewItem::paintPixmap( TQPainter *p, const TQColorGroup &cg )
#if 1 // FIXME
// Move the pixmap manually because the pixmapRect is at the
// top of the itemRect
// (won't be needed anymore in future versions of qt)
if ( d && !d->m_pixmapSize.isNull() )
{
@@ -723,7 +723,7 @@ void KIconViewItem::paintText( TQPainter *p, const TQColorGroup &cg )
}
p->setPen( TQPen( cg.highlightedText() ) );
} else {
- if ( iconView()->itemTextBackground() != NoBrush )
+ if ( iconView()->itemTextBackground() != Qt::NoBrush )
p->fillRect( textRect( false ), iconView()->itemTextBackground() );
p->setPen( cg.text() );
}
@@ -507,9 +507,9 @@ void KIconViewItem::calcRect( const TQString& text_ )
#if 1 // FIXME
// There is a bug in Qt which prevents the item from being placed
- // properly when the pixmapRect is not at the top of the itemRect, so we
+ // properly when the pixmapRect is not at the top of the tqitemRect, so we
// have to increase the height of the pixmapRect and leave it at the top
@@ -680,7 +680,7 @@ void KIconViewItem::paintPixmap( TQPainter *p, const TQColorGroup &cg )
#if 1 // FIXME
// Move the pixmap manually because the pixmapRect is at the
- // top of the itemRect
+ // top of the tqitemRect
// (won't be needed anymore in future versions of qt)
if ( d && !d->m_pixmapSize.isNull() )